@@ -8,20 +8,17 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_apigateway._jsii
-import aws_cdk.aws_cognito._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.core._jsii
+from typeguard import check_type
+
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-cognito-apigateway-lambda",
-    "1.149.0",
+    "2.23.0",
     __name__[0:-6],
-    "aws-cognito-apigateway-lambda@1.149.0.jsii.tgz",
+    "aws-cognito-apigateway-lambda@2.23.0.jsii.tgz",
 )
 
 __all__ = [
